@@ -16,19 +16,26 @@
  *  version 2, or at your option any later version.
  */
 
+#ifndef HAVE_CONFIG_H
+/* override HTUtils.h fallbacks for cross-compiling */
+#undef HAVE_LSTAT
+#undef NO_FILIO_H
+#define HAVE_LSTAT 1
+#define NO_FILIO_H 1
+#endif
+
+#define DONT_USE_GETTEXT
 #define DONT_USE_SOCKS5
-#include <HTUtils.h>
+#include <UCDefs.h>
+#include <UCkd.h>
 
 /*
- *  Don't try to use LYexit().
+ *  Don't try to use LYexit() since this is a standalone file.
  */
 #ifdef exit
 #undef exit
 #endif /* exit */
 
-#include <UCkd.h>
-#include <UCDefs.h>
-
 #define MAX_FONTLEN 256
 
 /*
@@ -41,20 +48,24 @@ static FILE *chdr = 0;
 /*
  * Since we may be writing the formatted file to stdout, ensure that we flush
  * everything before leaving, since some old (and a few not-so-old) platforms
- * that do not implement POSIX 'exit()'.
+ * do not properly implement POSIX 'exit()'.
  */
-PRIVATE void done PARAMS((int code)) GCC_NORETURN;
-PRIVATE void done ARGS1(int, code)
+static void done(int code) GCC_NORETURN;
+
+static void done(int code)
 {
-    fflush(chdr);
-    fclose(chdr);
+    if (chdr != 0) {
+	fflush(chdr);
+	fclose(chdr);
+    }
     fflush(stderr);
     exit(code);
 }
 
-PRIVATE void usage NOARGS
+static void usage(void)
 {
-    static CONST char *tbl[] = {
+    static const char *tbl[] =
+    {
 	"Usage: makeuctb [parameters]",
 	"",
 	"Utility to convert .tbl into .h files for Lynx compilation.",
@@ -66,6 +77,7 @@ PRIVATE void usage NOARGS
 	"  4: charset display name"
     };
     unsigned n;
+
     for (n = 0; n < TABLESIZE(tbl); n++) {
 	fprintf(stderr, "%s\n", tbl[n]);
     };
@@ -73,39 +85,36 @@ PRIVATE void usage NOARGS
 }
 
 #ifdef EXP_ASCII_CTYPES
-PUBLIC int ascii_tolower ARGS1(int, i)
+int ascii_tolower(int i)
 {
-    if ( 91 > i && i > 64 )
-	return (i+32);
+    if (91 > i && i > 64)
+	return (i + 32);
     else
 	return i;
 }
 #endif
 
 /* copied from HTString.c, not everybody has strncasecmp */
-PUBLIC int strncasecomp ARGS3(
-	CONST char*,	a,
-	CONST char *,	b,
-	int,		n)
+int strncasecomp(const char *a, const char *b, int n)
 {
-    CONST char *p = a;
-    CONST char *q = b;
+    const char *p = a;
+    const char *q = b;
 
-    for (p = a, q = b; ; p++, q++) {
+    for (p = a, q = b;; p++, q++) {
 	int diff;
-	if (p == (a+n))
-	    return 0;	/*   Match up to n characters */
+
+	if (p == (a + n))
+	    return 0;		/*   Match up to n characters */
 	if (!(*p && *q))
 	    return (*p - *q);
 	diff = TOLOWER(*p) - TOLOWER(*q);
 	if (diff)
 	    return diff;
     }
-    /*NOTREACHED*/
+    /*NOTREACHED */
 }
 
-PRIVATE int getunicode ARGS1(
-	char **,	p0)
+static int getunicode(char **p0)
 {
     char *p = *p0;
 
@@ -119,44 +128,44 @@ PRIVATE int getunicode ARGS1(
 	       !isxdigit(UCH(p[3])) ||
 	       !isxdigit(UCH(p[4])) ||
 	       !isxdigit(UCH(p[5])) ||
-	        isxdigit(UCH(p[6]))) {
+	       isxdigit(UCH(p[6]))) {
 	return -1;
     }
-    *p0 = p+6;
+    *p0 = p + 6;
     return strtol((p + 2), 0, 16);
 }
 
 /*
  *  Massive overkill, but who cares?
  */
-unicode unitable[MAX_FONTLEN][255];
-int unicount[MAX_FONTLEN];
+static unicode unitable[MAX_FONTLEN][255];
+static int unicount[MAX_FONTLEN];
 
-struct unimapdesc_str themap_str = {0, NULL, 0, 0};
+static struct unimapdesc_str themap_str =
+{0, NULL, 0, 0};
 
-PRIVATE char *tblname;
-PRIVATE char *hdrname;
+static const char *tblname;
+static const char *hdrname;
 
-PRIVATE int RawOrEnc = 0;
-PRIVATE int Raw_found = 0;		/* whether explicit R directive found */
-PRIVATE int CodePage = 0;
-PRIVATE int CodePage_found = 0;		/* whether explicit C directive found */
+static int RawOrEnc = 0;
+static int Raw_found = 0;	/* whether explicit R directive found */
+static int CodePage = 0;
+static int CodePage_found = 0;	/* whether explicit C directive found */
 
 #define MAX_UNIPAIRS 2500
 
-PRIVATE void addpair_str ARGS2(
-	char *,		str,
-	int,		un)
+static void addpair_str(char *str, int un)
 {
-   int i = 0;
+    int i = 0;
 
     if (un <= 0xfffe) {
 	if (!themap_str.entry_ct) {
 	    /*
 	     *  Initialize the map for replacement strings.
 	     */
-	    themap_str.entries = (struct unipair_str *) malloc (MAX_UNIPAIRS
-				* sizeof (struct unipair_str));
+	    themap_str.entries = (struct unipair_str *) malloc(MAX_UNIPAIRS
+							       * sizeof(struct unipair_str));
+
 	    if (!themap_str.entries) {
 		fprintf(stderr,
 			"%s: Out of memory\n", tblname);
@@ -166,8 +175,8 @@ PRIVATE void addpair_str ARGS2(
 	    /*
 	     *  Check that it isn't a duplicate.
 	     */
-	    for (i = 0 ; i < themap_str.entry_ct; i++) {
-		if (themap_str.entries[i].unicode == un ) {
+	    for (i = 0; i < themap_str.entry_ct; i++) {
+		if (themap_str.entries[i].unicode == un) {
 		    themap_str.entries[i].replace_str = str;
 		    return;
 		}
@@ -177,7 +186,7 @@ PRIVATE void addpair_str ARGS2(
 	/*
 	 *  Add to list.
 	 */
-	if (themap_str.entry_ct > MAX_UNIPAIRS-1) {
+	if (themap_str.entry_ct > MAX_UNIPAIRS - 1) {
 	    fprintf(stderr,
 		    "ERROR: Only %d unicode replacement strings permitted!\n",
 		    MAX_UNIPAIRS);
@@ -190,24 +199,22 @@ PRIVATE void addpair_str ARGS2(
     /* otherwise: ignore */
 }
 
-PRIVATE void addpair ARGS2(
-	int,	fp,
-	int,	un)
+static void addpair(int fp, int un)
 {
     int i;
 
-    if (!Raw_found) {	/* enc not (yet) explicitly given with 'R' */
+    if (!Raw_found) {		/* enc not (yet) explicitly given with 'R' */
 	if (fp >= 128) {
 	    if (RawOrEnc != UCT_ENC_8BIT && RawOrEnc <= UCT_ENC_8859) {
 		if (fp < 160) {	/* cannot be 8859 */
 		    RawOrEnc = UCT_ENC_8BIT;
 		} else if (fp != 160 && fp != 173) {
-		    RawOrEnc = UCT_ENC_8859; /* hmmm.. more tests needed? */
+		    RawOrEnc = UCT_ENC_8859;	/* hmmm.. more tests needed? */
 		} else if (unicount[fp] == 0 && fp != un) {
 		    /* first unicode for fp doesn't map to itself */
 		    RawOrEnc = UCT_ENC_8BIT;
 		} else {
-		    RawOrEnc = UCT_ENC_8859; /* hmmm.. more tests needed? */
+		    RawOrEnc = UCT_ENC_8859;	/* hmmm.. more tests needed? */
 		}
 	    }
 	}
@@ -235,18 +242,17 @@ PRIVATE void addpair ARGS2(
     /* otherwise: ignore */
 }
 
-char this_MIMEcharset[UC_MAXLEN_MIMECSNAME +1];
-char this_LYNXcharset[UC_MAXLEN_LYNXCSNAME +1];
-char id_append[UC_MAXLEN_ID_APPEND +1] = "_";
-int this_isDefaultMap = -1;
-int useDefaultMap = 1;
-int lowest_eight = 999;
+static char this_MIMEcharset[UC_MAXLEN_MIMECSNAME + 1];
+static char this_LYNXcharset[UC_MAXLEN_LYNXCSNAME + 1];
+static char id_append[UC_MAXLEN_ID_APPEND + 1] = "_";
+static int this_isDefaultMap = -1;
+static int useDefaultMap = 1;
+static int lowest_eight = 999;
 
-PUBLIC int main ARGS2(
-	int,		argc,
-	char **,	argv)
+int main(int argc, char **argv)
 {
-    static char *first_ifdefs[] = {
+    static const char *first_ifdefs[] =
+    {
 	"/*",
 	" * Compile-in this chunk of code unless we've turned it off specifically",
 	" * or in general (id=%s).",
@@ -276,7 +282,8 @@ PUBLIC int main ARGS2(
 	"#define UC_CHARSET_SETUP%s /*nothing*/",
 	"#else"
     };
-    static char *last_ifdefs[] = {
+    static const char *last_ifdefs[] =
+    {
 	"",
 	"#endif /* NO_CHARSET%s */",
 	"",
@@ -319,7 +326,8 @@ PUBLIC int main ARGS2(
 	chdr = stdout;
 	hdrname = "stdout";
     } else {
-	strcpy(hdrname = outname, tblname);
+	strcpy(outname, tblname);
+	hdrname = outname;
 	if ((p = strrchr(outname, '.')) == 0)
 	    p = outname + strlen(outname);
 	strcpy(p, ".h");
@@ -359,15 +367,15 @@ PUBLIC int main ARGS2(
 
 	/*
 	 *  Syntax accepted:
-	 *	<fontpos>	<unicode> <unicode> ...
-	 *	<fontpos>	<unicode range> <unicode range> ...
-	 *	<fontpos>	idem
-	 *	<range>		idem
-	 *	<range>		<unicode range>
-	 *      <unicode>	:<replace>
-	 *      <unicode range>	:<replace>
-	 *      <unicode>	"<C replace>"
-	 *      <unicode range>	"<C replace>"
+	 *      <fontpos>       <unicode> <unicode> ...
+	 *      <fontpos>       <unicode range> <unicode range> ...
+	 *      <fontpos>       idem
+	 *      <range>         idem
+	 *      <range>         <unicode range>
+	 *      <unicode>       :<replace>
+	 *      <unicode range> :<replace>
+	 *      <unicode>       "<C replace>"
+	 *      <unicode range> "<C replace>"
 	 *
 	 *  where <range> ::= <fontpos>-<fontpos>
 	 *  and <unicode> ::= U+<h><h><h><h>
@@ -391,106 +399,106 @@ PUBLIC int main ARGS2(
 	     *  Raw Unicode?  I.e. needs some special
 	     *  processing.  One digit code.
 	     */
-	    case 'R':
-		if (p[1] == 'a' || p[1] == 'A') {
-		    buffer[sizeof(buffer) - 1] = '\0';
-		    if (!strncasecomp(p, "RawOrEnc", 8)) {
-			p += 8;
-		    }
+	case 'R':
+	    if (p[1] == 'a' || p[1] == 'A') {
+		buffer[sizeof(buffer) - 1] = '\0';
+		if (!strncasecomp(p, "RawOrEnc", 8)) {
+		    p += 8;
 		}
+	    }
+	    p++;
+	    while (*p == ' ' || *p == '\t') {
 		p++;
-		while (*p == ' ' || *p == '\t') {
-		    p++;
-		}
-		RawOrEnc = strtol(p,0,10);
-		Raw_found = 1;
-		continue;
+	    }
+	    RawOrEnc = strtol(p, 0, 10);
+	    Raw_found = 1;
+	    continue;
 
 	    /*
 	     *  Is this the default table?
 	     */
-	    case 'D':
-		if (p[1] == 'e' || p[1] == 'E') {
-		    buffer[sizeof(buffer) - 1] = '\0';
-		    if (!strncasecomp(p, "Default", 7)) {
-			p += 7;
-		    }
+	case 'D':
+	    if (p[1] == 'e' || p[1] == 'E') {
+		buffer[sizeof(buffer) - 1] = '\0';
+		if (!strncasecomp(p, "Default", 7)) {
+		    p += 7;
 		}
+	    }
+	    p++;
+	    while (*p == ' ' || *p == '\t') {
 		p++;
-		while (*p == ' ' || *p == '\t') {
-		    p++;
-		}
-		this_isDefaultMap = (*p == '1' || TOLOWER(*p) == 'y');
-		continue;
+	    }
+	    this_isDefaultMap = (*p == '1' || TOLOWER(*p) == 'y');
+	    continue;
 
 	    /*
 	     *  Is this the default table?
 	     */
-	    case 'F':
-		if (p[1] == 'a' || p[1] == 'A') {
-		    buffer[sizeof(buffer) - 1] = '\0';
-		    if (!strncasecomp(p, "FallBack", 8)) {
-			p += 8;
-		    }
+	case 'F':
+	    if (p[1] == 'a' || p[1] == 'A') {
+		buffer[sizeof(buffer) - 1] = '\0';
+		if (!strncasecomp(p, "FallBack", 8)) {
+		    p += 8;
 		}
+	    }
+	    p++;
+	    while (*p == ' ' || *p == '\t') {
 		p++;
-		while (*p == ' ' || *p == '\t') {
-		    p++;
-		}
-		useDefaultMap = (*p == '1' || TOLOWER(*p) == 'y');
-		continue;
+	    }
+	    useDefaultMap = (*p == '1' || TOLOWER(*p) == 'y');
+	    continue;
 
-	    case 'M':
-		if (p[1] == 'i' || p[1] == 'I') {
-		    buffer[sizeof(buffer) - 1] = '\0';
-		    if (!strncasecomp(p, "MIMEName", 8)) {
-			p += 8;
-		    }
+	case 'M':
+	    if (p[1] == 'i' || p[1] == 'I') {
+		buffer[sizeof(buffer) - 1] = '\0';
+		if (!strncasecomp(p, "MIMEName", 8)) {
+		    p += 8;
 		}
+	    }
+	    p++;
+	    while (*p == ' ' || *p == '\t') {
 		p++;
-		while (*p == ' ' || *p == '\t') {
-		    p++;
-		}
-		sscanf(p,"%40s",this_MIMEcharset);
-		continue;
+	    }
+	    sscanf(p, "%40s", this_MIMEcharset);
+	    continue;
 
 	    /*
 	     *  Display charset name for options screen.
 	     */
-	    case 'O':
-		if (p[1] == 'p' || p[1] == 'P') {
-		    buffer[sizeof(buffer) - 1] = '\0';
-		    if (!strncasecomp(p, "OptionName", 10)) {
-			p += 10;
-		    }
+	case 'O':
+	    if (p[1] == 'p' || p[1] == 'P') {
+		buffer[sizeof(buffer) - 1] = '\0';
+		if (!strncasecomp(p, "OptionName", 10)) {
+		    p += 10;
 		}
+	    }
+	    p++;
+	    while (*p == ' ' || *p == '\t') {
 		p++;
-		while (*p == ' ' || *p == '\t') {
-		    p++;
-		}
-		for (i = 0; *p && i < UC_MAXLEN_LYNXCSNAME; p++, i++) {
-		    this_LYNXcharset[i] = *p;
-		}
-		this_LYNXcharset[i] = '\0';
-		continue;
+	    }
+	    for (i = 0; *p && i < UC_MAXLEN_LYNXCSNAME; p++, i++) {
+		this_LYNXcharset[i] = *p;
+	    }
+	    this_LYNXcharset[i] = '\0';
+	    continue;
 
 	    /*
 	     *  Codepage number.  Three or four digit code.
 	     */
-	    case 'C':
-		if (p[1] == 'o' || p[1] == 'O') {
-		    buffer[sizeof(buffer) - 1] = '\0';
-		    if (!strncasecomp(p, "CodePage", 8)) {
-			p += 8;
-		    }
+	case 'C':
+	    if (p[1] == 'o' || p[1] == 'O') {
+		buffer[sizeof(buffer) - 1] = '\0';
+		if (!strncasecomp(p, "CodePage", 8)) {
+		    p += 8;
 		}
+	    }
+	    p++;
+	    while (*p == ' ' || *p == '\t') {
 		p++;
-		while (*p == ' ' || *p == '\t') {
-		    p++;
-		}
-		CodePage = strtol(p,0,10);
-		CodePage_found = 1;
-		continue;
+	    }
+	    CodePage = strtol(p, 0, 10);
+	    CodePage_found = 1;
+	    continue;
 	}
 
 	if (*p == 'U') {
@@ -499,7 +507,7 @@ PUBLIC int main ARGS2(
 		fprintf(stderr, "Bad input line: %s\n", buffer);
 		done(EX_DATAERR);
 		fprintf(stderr,
-    "%s: Bad Unicode range corresponding to font position range 0x%x-0x%x\n",
+			"%s: Bad Unicode range corresponding to font position range 0x%x-0x%x\n",
 			tblname, fp0, fp1);
 		done(EX_DATAERR);
 	    }
@@ -531,7 +539,7 @@ PUBLIC int main ARGS2(
 		continue;
 	    }
 
-	    tbuf = (char *)malloc(4*strlen(p));
+	    tbuf = (char *) malloc(4 * strlen(p));
 
 	    if (!(p1 = tbuf)) {
 		fprintf(stderr, "%s: Out of memory\n", tblname);
@@ -544,6 +552,7 @@ PUBLIC int main ARGS2(
 		 *  end of buffer.
 		 */
 		int escaped = 0;
+
 		for (ch = *(++p); (ch = *p) != '\0'; p++) {
 		    if (escaped) {
 			escaped = 0;
@@ -568,9 +577,6 @@ PUBLIC int main ARGS2(
 		    if (UCH(ch) < 32 || ch == '\\' || ch == '\"' ||
 			UCH(ch) >= 127) {
 			sprintf(p1, "\\%.3o", UCH(ch));
-#ifdef NOTDEFINED
-			fprintf(stderr, "%s\n", tbuf);
-#endif /* NOTDEFINED */
 			p1 += 3;
 		    } else {
 			*p1 = ch;
@@ -579,10 +585,7 @@ PUBLIC int main ARGS2(
 	    }
 	    *p1 = '\0';
 	    for (i = un0; i <= un1; i++) {
-#ifdef NOTDEFINED
-		fprintf(chdr, "U+0x%x:%s\n", i, tbuf); */
-#endif /* NOTDEFINED */
-		addpair_str(tbuf,i);
+		addpair_str(tbuf, i);
 	    }
 	    continue;
 	}
@@ -637,7 +640,7 @@ PUBLIC int main ARGS2(
 	    }
 	    if (!strncmp(p, "idem", 4)) {
 		for (i = fp0; i <= fp1; i++) {
-		    addpair(i,i);
+		    addpair(i, i);
 		}
 		p += 4;
 	    } else {
@@ -657,13 +660,13 @@ PUBLIC int main ARGS2(
 		un1 = getunicode(&p);
 		if (un0 < 0 || un1 < 0) {
 		    fprintf(stderr,
-     "%s: Bad Unicode range corresponding to font position range 0x%x-0x%x\n",
+			    "%s: Bad Unicode range corresponding to font position range 0x%x-0x%x\n",
 			    tblname, fp0, fp1);
 		    done(EX_DATAERR);
 		}
 		if (un1 - un0 != fp1 - fp0) {
 		    fprintf(stderr,
-			"%s: Unicode range U+%x-U+%x not of the same length",
+			    "%s: Unicode range U+%x-U+%x not of the same length",
 			    tblname, un0, un1);
 		    fprintf(stderr,
 			    " as font position range 0x%x-0x%x\n",
@@ -671,7 +674,7 @@ PUBLIC int main ARGS2(
 		    done(EX_DATAERR);
 		}
 		for (i = fp0; i <= fp1; i++) {
-		    addpair(i,un0-fp0+i);
+		    addpair(i, un0 - fp0 + i);
 		}
 	    }
 	} else {
@@ -684,7 +687,7 @@ PUBLIC int main ARGS2(
 		p++;
 	    }
 	    if (!strncmp(p, "idem", 4)) {
-		addpair(fp0,fp0);
+		addpair(fp0, fp0);
 		p += 4;
 	    }
 	    while ((un0 = getunicode(&p)) >= 0) {
@@ -720,20 +723,19 @@ PUBLIC int main ARGS2(
      */
     fclose(ctbl);
 
-
     /*
      *  Compute total size of Unicode list.
      */
     nuni = 0;
-    for (i = 0 ; i < fontlen ; i++) {
+    for (i = 0; i < fontlen; i++) {
 	nuni += unicount[i];
     }
 
     if (argc > 3) {
-	strncpy(this_MIMEcharset,argv[3],UC_MAXLEN_MIMECSNAME);
+	strncpy(this_MIMEcharset, argv[3], UC_MAXLEN_MIMECSNAME);
     } else if (this_MIMEcharset[0] == '\0') {
-	strncpy(this_MIMEcharset,tblname,UC_MAXLEN_MIMECSNAME);
-	if ((p = strchr(this_MIMEcharset,'.')) != 0) {
+	strncpy(this_MIMEcharset, tblname, UC_MAXLEN_MIMECSNAME);
+	if ((p = strchr(this_MIMEcharset, '.')) != 0) {
 	    *p = '\0';
 	}
     }
@@ -741,24 +743,13 @@ PUBLIC int main ARGS2(
 	*p = TOLOWER(*p);
     }
     if (argc > 4) {
-	strncpy(this_LYNXcharset,argv[4],UC_MAXLEN_LYNXCSNAME);
+	strncpy(this_LYNXcharset, argv[4], UC_MAXLEN_LYNXCSNAME);
     } else if (this_LYNXcharset[0] == '\0') {
-	strncpy(this_LYNXcharset,this_MIMEcharset,UC_MAXLEN_LYNXCSNAME);
+	strncpy(this_LYNXcharset, this_MIMEcharset, UC_MAXLEN_LYNXCSNAME);
     }
-/***** DO NOT produce trailing spaces!
-    if ((i = strlen(this_LYNXcharset)) < UC_LEN_LYNXCSNAME) {
-	for (; i < UC_LEN_LYNXCSNAME; i++) {
-	    this_LYNXcharset[i] = ' ';
-	}
-	this_LYNXcharset[i] = '\0';
-    }
-*******/
-#ifdef NOTDEFINED
-    fprintf(stderr,"this_MIMEcharset: %s.\n",this_MIMEcharset);
-    fprintf(stderr,"this_LYNXcharset: %s.\n",this_LYNXcharset);
-#endif /* NOTDEFINED */
+
     if (this_isDefaultMap == -1) {
-	this_isDefaultMap = !strncmp(this_MIMEcharset,"iso-8859-1", 10);
+	this_isDefaultMap = !strncmp(this_MIMEcharset, "iso-8859-1", 10);
     }
     fprintf(stderr,
 	    "makeuctb: %s: %stranslation map",
@@ -767,11 +758,11 @@ PUBLIC int main ARGS2(
 	*id_append = '\0';
     } else {
 	for (i = 0, p = this_MIMEcharset;
-	     *p && (i < UC_MAXLEN_ID_APPEND-1);
+	     *p && (i < UC_MAXLEN_ID_APPEND - 1);
 	     p++, i++) {
-	    id_append[i+1] = isalnum(UCH(*p)) ? *p : '_';
+	    id_append[i + 1] = isalnum(UCH(*p)) ? *p : '_';
 	}
-	id_append[i+1] = '\0';
+	id_append[i + 1] = '\0';
     }
     fprintf(stderr, " (%s).\n", id_append);
 
@@ -790,7 +781,7 @@ PUBLIC int main ARGS2(
  *\n\
  */\n\
 \n\
-static CONST u8 dfont_unicount%s[%d] = \n\
+static const u8 dfont_unicount%s[%d] = \n\
 {\n\t", argv[0], argv[1], id_append, fontlen);
 
     for (i = 0; i < fontlen; i++) {
@@ -816,10 +807,11 @@ static CONST u8 dfont_unicount%s[%d] = \n\
     }
 
     if (nuni) {
-	fprintf(chdr, "\nstatic CONST u16 dfont_unitable%s[%d] = \n{\n\t",
+	fprintf(chdr, "\nstatic const u16 dfont_unitable%s[%d] = \n{\n\t",
 		id_append, nuni);
     } else {
-	fprintf(chdr, "\nstatic CONST u16 dfont_unitable%s[1]; /* dummy */\n", id_append);
+	fprintf(chdr,
+		"\nstatic const u16 dfont_unitable%s[1] = {0}; /* dummy */\n", id_append);
     }
 
     fp0 = 0;
@@ -862,24 +854,23 @@ static struct unipair_str repl_map%s[%d] = \n\
     }
     if (themap_str.entry_ct) {
 	fprintf(chdr, "\n\
-static CONST struct unimapdesc_str dfont_replacedesc%s = {%d,repl_map%s,",
-id_append, themap_str.entry_ct, id_append);
+static const struct unimapdesc_str dfont_replacedesc%s = {%d,repl_map%s,",
+		id_append, themap_str.entry_ct, id_append);
     } else {
 	fprintf(chdr, "\n\
-static CONST struct unimapdesc_str dfont_replacedesc%s = {0,NULL,",id_append);
+static const struct unimapdesc_str dfont_replacedesc%s = {0,NULL,", id_append);
     }
     fprintf(chdr, "%d,%d};\n",
 	    this_isDefaultMap ? 1 : 0,
 	    (useDefaultMap && !this_isDefaultMap) ? 1 : 0
-    );
-
+	);
 
     fprintf(chdr, "#define UC_CHARSET_SETUP%s UC_Charset_Setup(\
 \"%s\",\\\n\"%s\",\\\n\
 dfont_unicount%s,dfont_unitable%s,%d,\\\n\
 dfont_replacedesc%s,%d,%d,%d)\n",
-id_append, this_MIMEcharset, this_LYNXcharset,
-id_append, id_append, nuni, id_append, lowest_eight, RawOrEnc, CodePage);
+	    id_append, this_MIMEcharset, this_LYNXcharset,
+	    id_append, id_append, nuni, id_append, lowest_eight, RawOrEnc, CodePage);
 
     for (n = 0; n < TABLESIZE(last_ifdefs); n++) {
 	fprintf(chdr, last_ifdefs[n], id_append);
